"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.CheckboxGroup = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _styleToObj = _interopRequireDefault(require("../utils/style-to-obj"));
var _styles = _interopRequireDefault(require("./styles"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const defaultProps = {
  disabled: false,
  checkedValue: [],
  max: undefined,
  onChange: value => {},
  style: {}
};
const CheckboxGroup = /*#__PURE__*/_react.default.forwardRef((props, ref) => {
  const {
    children
  } = {
    ...defaultProps,
    ...props
  };
  const {
    disabled,
    onChange,
    checkedValue,
    max,
    style
  } = props;
  const styles = (0, _styles.default)();
  const [innerDisabled, setInnerDisabled] = (0, _react.useState)(disabled);
  const [innerValue, setInnerValue] = (0, _react.useState)(checkedValue);
  (0, _react.useImperativeHandle)(ref, () => ({
    toggleAll(state) {
      if (state === false) {
        setInnerValue([]);
      } else {
        const childrenLabel = [];
        _react.default.Children.map(children, child => {
          const childProps = child.props;
          childrenLabel.push(childProps.label || child.children);
        });
        setInnerValue(childrenLabel);
      }
    },
    toggleReverse() {
      const childrenLabel = [];
      _react.default.Children.map(children, child => {
        const childProps = child.props;
        childrenLabel.push(childProps.label || child.children);
      });
      const reverse = childrenLabel.filter(c => (innerValue === null || innerValue === void 0 ? void 0 : innerValue.findIndex(v => v === c)) === -1);
      setInnerValue(reverse);
    }
  }));
  (0, _react.useEffect)(() => {
    setInnerDisabled(disabled);
    setInnerValue(checkedValue);
  }, [disabled, checkedValue]);
  function handleChildChange(state, label) {
    if (max !== undefined && innerValue && innerValue.length > max) return;
    if (innerValue) {
      let clippedValue = [];
      if (state) {
        clippedValue = [...innerValue, label];
      } else {
        innerValue === null || innerValue === void 0 ? void 0 : innerValue.splice(innerValue === null || innerValue === void 0 ? void 0 : innerValue.indexOf(label), 1);
        clippedValue = [...innerValue];
      }
      setInnerValue(clippedValue);
      onChange && onChange(clippedValue);
    }
  }
  function validateChildChecked(child) {
    if (!innerValue) return false;
    return (innerValue === null || innerValue === void 0 ? void 0 : innerValue.indexOf(child.props.label || child.children)) > -1;
  }
  function getParentVals() {
    return innerValue;
  }
  function cloneChildren() {
    return _react.default.Children.map(children, child => {
      const childChecked = validateChildChecked(child);
      if (child.type.displayName !== 'NutCheckBox') {
        return /*#__PURE__*/_react.default.cloneElement(child);
      }
      return /*#__PURE__*/_react.default.cloneElement(child, {
        disabled: innerDisabled,
        checked: childChecked,
        onChange: handleChildChange,
        getParentVals,
        max
      });
    });
  }
  const wrapStyle = [styles.container, (0, _styleToObj.default)(style || {})];
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: wrapStyle
  }, cloneChildren());
});
exports.CheckboxGroup = CheckboxGroup;
CheckboxGroup.defaultProps = defaultProps;
CheckboxGroup.displayName = 'NutCheckboxGroup';
//# sourceMappingURL=checkboxgroup.js.map