"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.CountDown = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _styleToObj = _interopRequireDefault(require("../utils/style-to-obj"));
var _filterContainerStyle = _interopRequireDefault(require("../utils/filter-container-style"));
var _configprovider = require("../configprovider/configprovider");
var _styles = _interopRequireDefault(require("./styles"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const defaultProps = {
  paused: false,
  startTime: Date.now(),
  endTime: Date.now(),
  millisecond: false,
  format: 'HH:mm:ss',
  autoStart: true,
  time: 0
};
const InternalCountDown = /*#__PURE__*/(0, _react.forwardRef)((props, ref) => {
  const {
    locale
  } = (0, _configprovider.useConfig)();
  const styles = (0, _styles.default)();
  const {
    paused,
    startTime,
    endTime,
    millisecond,
    format,
    autoStart,
    time,
    style,
    onEnd,
    onPaused,
    onRestart,
    onUpdate,
    children,
    ...rest
  } = {
    ...defaultProps,
    ...props
  };
  const [restTimeStamp, setRestTime] = (0, _react.useState)(0);
  const stateRef = (0, _react.useRef)({
    pauseTime: 0,
    curr: 0,
    isPaused: paused,
    isIninted: false,
    timer: 0,
    restTime: 0,
    // 倒计时剩余时间时间
    counting: !paused && autoStart,
    // 是否处于倒计时中
    handleEndTime: Date.now(),
    // 最终截止时间
    diffTime: 0 // 设置了 startTime 时，与 date.now() 的差异
  });

  // 时间戳转换 或 获取当前时间的时间戳
  const getTimeStamp = timeStr => {
    if (!timeStr) return Date.now();
    let t = timeStr;
    t = t > 0 ? +t : t.toString().replace(/-/g, '/');
    return new Date(t).getTime();
  };

  // 倒计时 interval
  const initTime = () => {
    stateRef.current.handleEndTime = endTime;
    stateRef.current.diffTime = Date.now() - getTimeStamp(startTime); // 时间差
    if (!stateRef.current.counting) stateRef.current.counting = true;
    tick();
  };
  const tick = () => {
    stateRef.current.timer = +setTimeout(() => {
      if (stateRef.current.counting) {
        const currentTime = Date.now() - stateRef.current.diffTime;
        const remainTime = Math.max(stateRef.current.handleEndTime - currentTime, 0);
        stateRef.current.restTime = remainTime;
        setRestTime(remainTime);
        if (!remainTime) {
          stateRef.current.counting = false;
          pause();
          onEnd && onEnd();
        }
        if (remainTime > 0) {
          tick();
        }
      }
    });
  };

  // 将倒计时剩余时间格式化   参数： t  时间戳  type custom 自定义类型
  const formatRemainTime = (t, type) => {
    const ts = t;
    const rest = {
      d: 0,
      h: 0,
      m: 0,
      s: 0,
      ms: 0
    };
    const SECOND = 1000;
    const MINUTE = 60 * SECOND;
    const HOUR = 60 * MINUTE;
    const DAY = 24 * HOUR;
    if (ts > 0) {
      rest.d = ts >= SECOND ? Math.floor(ts / DAY) : 0;
      rest.h = Math.floor(ts % DAY / HOUR);
      rest.m = Math.floor(ts % HOUR / MINUTE);
      rest.s = Math.floor(ts % MINUTE / SECOND);
      rest.ms = Math.floor(ts % SECOND);
    }
    return type === 'custom' ? rest : parseFormat({
      ...rest
    });
  };
  const parseFormat = time => {
    const {
      d
    } = time;
    let {
      h,
      m,
      s,
      ms
    } = time;
    let formatCache = format;
    if (formatCache.includes('DD')) {
      formatCache = formatCache.replace('DD', padZero(d));
    } else {
      h += Number(d) * 24;
    }
    if (formatCache.includes('HH')) {
      formatCache = formatCache.replace('HH', padZero(h));
    } else {
      m += Number(h) * 60;
    }
    if (formatCache.includes('mm')) {
      formatCache = formatCache.replace('mm', padZero(m));
    } else {
      s += Number(m) * 60;
    }
    if (formatCache.includes('ss')) {
      formatCache = formatCache.replace('ss', padZero(s));
    } else {
      ms += Number(s) * 1000;
    }
    if (formatCache.includes('S')) {
      const msC = padZero(ms, 3).toString();
      if (formatCache.includes('SSS')) {
        formatCache = formatCache.replace('SSS', msC);
      } else if (formatCache.includes('SS')) {
        formatCache = formatCache.replace('SS', msC.slice(0, 2));
      } else if (formatCache.includes('S')) {
        formatCache = formatCache.replace('SS', msC.slice(0, 1));
      }
    }
    return formatCache;
  };
  const padZero = function (num) {
    let length = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 2;
    num += '';
    while (num.length < length) {
      num = `0${num}`;
    }
    return num.toString();
  };

  // 暂定
  const pause = () => {
    // cancelAnimationFrame(stateRef.current.timer)
    clearTimeout(stateRef.current.timer);
    stateRef.current.counting = false;
    onPaused && onPaused(stateRef.current.restTime);
  };
  (0, _react.useImperativeHandle)(ref, () => ({
    start: () => {
      if (!stateRef.current.counting && !autoStart) {
        stateRef.current.counting = true;
        stateRef.current.handleEndTime = Date.now() + Number(stateRef.current.restTime);
        tick();
        onRestart && onRestart(stateRef.current.restTime);
      }
    },
    pause: () => {
      // cancelAnimationFrame(stateRef.current.timer)
      clearTimeout(stateRef.current.timer);
      stateRef.current.counting = false;
      onPaused && onPaused(stateRef.current.restTime);
    },
    reset: () => {
      if (!autoStart) {
        pause();
        stateRef.current.restTime = time;
        setRestTime(time);
      }
    }
  }));

  // 监听值变更
  (0, _react.useEffect)(() => {
    const tranTime = formatRemainTime(stateRef.current.restTime, 'custom');
    onUpdate && onUpdate(tranTime);
  }, [restTimeStamp]);

  // 监听暂停
  (0, _react.useEffect)(() => {
    if (stateRef.current.isIninted) {
      if (paused) {
        if (stateRef.current.counting) {
          pause();
        }
      } else {
        if (!stateRef.current.counting) {
          stateRef.current.counting = true;
          stateRef.current.handleEndTime = Date.now() + Number(stateRef.current.restTime);
          tick();
        }
        onRestart && onRestart(stateRef.current.restTime);
      }
    }
  }, [paused]);

  // 监听开始结束时间变更
  // useEffect(() => {
  //   if (stateRef.current.isIninted) {
  //     initTime()
  //   }
  // }, [endTime, startTime])

  // 初始化
  (0, _react.useEffect)(() => {
    if (autoStart) {
      initTime();
    } else {
      stateRef.current.restTime = time;
      setRestTime(time);
    }
    if (!stateRef.current.isIninted) {
      stateRef.current.isIninted = true;
    }
    return componentWillUnmount;
  }, []);
  const componentWillUnmount = () => {
    clearTimeout(stateRef.current.timer);
    clearInterval(stateRef.current.timer);
  };
  const renderTime = (() => {
    return formatRemainTime(stateRef.current.restTime);
  })();
  const wrapStyle = [styles.container, (0, _filterContainerStyle.default)((0, _styleToObj.default)(style || {}))];
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: wrapStyle
  }, children || /*#__PURE__*/_react.default.createElement(_reactNative.View, null, /*#__PURE__*/_react.default.createElement(_reactNative.Text, null, renderTime)));
});
const CountDown = InternalCountDown;
exports.CountDown = CountDown;
CountDown.defaultProps = defaultProps;
CountDown.displayName = 'NutCountDown';
//# sourceMappingURL=countdown.js.map