"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Drag = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _utils = require("../utils");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const defaultProps = {
  attract: false,
  direction: undefined,
  boundary: {
    top: 0,
    left: 0,
    right: 0,
    bottom: 0
  }
};
const Drag = props => {
  const {
    attract,
    direction,
    boundary,
    children,
    style,
    ...reset
  } = {
    ...defaultProps,
    ...props
  };
  const [boundaryState, setBoundaryState] = (0, _react.useState)(boundary);
  const {
    current: curTop
  } = _react.default.useRef(new _reactNative.Animated.Value(boundaryState.top));
  const {
    current: curLeft
  } = _react.default.useRef(new _reactNative.Animated.Value(boundaryState.left));
  const middleLine = (0, _react.useRef)(0);
  const touchX = (0, _react.useRef)(0);
  const touchY = (0, _react.useRef)(0);
  const getInfo = e => {
    const {
      x,
      y,
      width,
      height
    } = e.nativeEvent.layout;
    const offsetWidth = width;
    const offsetHeight = height;
    const offsetTop = y;
    const offsetLeft = x;
    const clientWidth = _utils.DiviceWidth;
    const clientHeight = _utils.DiviceHeight;
    const {
      top,
      left,
      bottom,
      right
    } = boundary;
    const boundaryState = {
      top: -offsetTop + top,
      left: -offsetLeft + left,
      bottom: clientHeight - offsetHeight - offsetTop - bottom,
      right: clientWidth - offsetWidth - offsetLeft - right
    };
    setBoundaryState(boundaryState);
    middleLine.current = clientWidth - offsetWidth - offsetLeft - (clientWidth - offsetWidth) / 2;
  };
  const panResponder = _reactNative.PanResponder.create({
    onStartShouldSetPanResponder: () => false,
    onStartShouldSetPanResponderCapture: () => false,
    onPanResponderTerminationRequest: () => false,
    // 这个很重要，这边不放权
    onShouldBlockNativeResponder: () => false,
    onMoveShouldSetPanResponder: (evt, g) => {
      // 解决PanResponder中的onPress无作用
      // 当大于5时才进入移动事件，有的情况下需要将onStartShouldSetPanResponderCapture设为false
      if (Math.abs(g.dx) > 5 || Math.abs(g.dy) > 5) {
        return true;
      } else if (Math.abs(g.dx) <= 5 || Math.abs(g.dy) <= 5) {
        return false;
      }
      return false;
    },
    onMoveShouldSetPanResponderCapture: () => false,
    onPanResponderGrant: () => {
      touchX.current = curLeft._value || 0;
      touchY.current = curTop._value || 0;
    },
    onPanResponderMove: (e, g) => {
      let left = touchX.current + g.dx;
      let top = touchY.current + g.dy;
      if (left <= boundaryState.left) {
        left = boundaryState.left;
      }
      if (left > boundaryState.right) {
        left = boundaryState.right;
      }
      if (top <= boundaryState.top) {
        top = boundaryState.top;
      }
      if (top >= boundaryState.bottom) {
        top = boundaryState.bottom;
      }
      if (direction === 'x') {
        top = touchY.current;
      }
      if (direction === 'y') {
        left = touchX.current;
      }
      curTop.setValue(top);
      curLeft.setValue(left);
    },
    onPanResponderRelease: () => {
      const left = curLeft._value || 0;
      const top = curTop._value || 0;
      if (direction !== 'y' && attract) {
        if (left < middleLine.current) {
          curLeft.setValue(boundaryState.left);
        } else {
          curLeft.setValue(boundaryState.right);
        }
      }
    }
  });
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, _extends({
    style: [styles.wrap, style]
  }, reset, {
    onLayout: getInfo
  }), /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, _extends({
    style: {
      transform: [{
        translateY: curTop
      }, {
        translateX: curLeft
      }]
    }
  }, panResponder.panHandlers), children));
};
exports.Drag = Drag;
Drag.defaultProps = defaultProps;
Drag.displayName = 'NutDrag';
const styles = _reactNative.StyleSheet.create({
  wrap: {
    position: 'absolute',
    zIndex: 9997
  }
});
//# sourceMappingURL=drag.js.map