"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.NavBar = void 0;
var _react = _interopRequireDefault(require("react"));
var _index = _interopRequireDefault(require("../icon/index"));
var _reactNative = require("react-native");
var _typings = require("../utils/typings");
var _statusBarHeight = _interopRequireDefault(require("../utils/statusBarHeight"));
var _pt = _interopRequireDefault(require("../utils/pt"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const defaultProps = {
  ..._typings.ComponentDefaults,
  title: '',
  desc: '',
  leftShow: true,
  titIcon: '',
  className: '',
  leftText: '',
  fixed: false,
  safeAreaInsetTop: false,
  border: false,
  placeholder: false,
  zIndex: 10,
  style: {},
  onClickTitle: () => {},
  onClickIcon: () => {},
  onClickBack: () => {},
  onClickRight: () => {}
};
const NavBar = props => {
  const {
    desc,
    title,
    titIcon,
    leftShow,
    className,
    style,
    leftText,
    fixed,
    safeAreaInsetTop,
    border,
    placeholder,
    zIndex,
    onClickTitle,
    onClickIcon,
    onClickBack,
    onClickRight,
    iconClassPrefix,
    iconFontClassName
  } = {
    ...defaultProps,
    ...props
  };
  const children = Array.isArray(props.children) ? props.children : [props.children];
  const slot = children.reduce((slot, item) => {
    const data = slot;
    if (item && item.props) {
      data[item.props.slot] = item;
    }
    return data;
  }, {});
  const customStyles = () => {
    return {
      ...style,
      zIndex
    };
  };
  const renderLeft = () => {
    return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
      style: mStyles.mLeft,
      onPress: e => onClickBack(e)
    }, leftShow && /*#__PURE__*/_react.default.createElement(_index.default, {
      classPrefix: iconClassPrefix,
      fontClassName: iconFontClassName,
      name: "left",
      color: "#979797",
      size: (0, _pt.default)(32)
    }), leftText ? /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: mStyles.marL10
    }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, null, leftText)) : null, slot.left);
  };
  const renderContent = () => {
    return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: mStyles.content
    }, title ? /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
      onPress: e => onClickTitle(e)
    }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, null, " ", title)) : null, titIcon ? /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
      onPress: e => onClickIcon(e),
      style: mStyles.marL10
    }, /*#__PURE__*/_react.default.createElement(_index.default, {
      classPrefix: iconClassPrefix,
      fontClassName: iconFontClassName,
      name: titIcon
    })) : null, slot.content);
  };
  const renderRight = () => {
    return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
      style: mStyles.mRright,
      onPress: e => onClickRight(e)
    }, desc ? /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: {
        marginRight: 10
      }
    }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, null, desc)) : null, slot.right);
  };
  const renderWrapper = () => {
    return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: [mStyles.wrapper, {
        width: '100%',
        borderBottomWidth: border ? 1 : 0,
        zIndex
      }, style]
    }, renderLeft(), renderContent(), renderRight());
  };
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, safeAreaInsetTop ? /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      paddingTop: _statusBarHeight.default
    }
  }, renderWrapper()) : renderWrapper());
};
exports.NavBar = NavBar;
const mStyles = _reactNative.StyleSheet.create({
  wrapper: {
    height: (0, _pt.default)(100),
    backgroundColor: '#fff',
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'center',
    borderBottomColor: '#f2f2f2'
  },
  content: {
    justifyContent: 'center',
    alignItems: 'center',
    flexDirection: 'row',
    height: '100%'
  },
  mRright: {
    height: '100%',
    justifyContent: 'center',
    alignItems: 'center',
    flexDirection: 'row',
    position: 'absolute',
    right: 0,
    top: 0
  },
  mLeft: {
    height: '100%',
    justifyContent: 'center',
    alignItems: 'center',
    flexDirection: 'row',
    position: 'absolute',
    left: 10,
    top: 0
  },
  marL10: {
    marginLeft: (0, _pt.default)(10)
  }
});
NavBar.defaultProps = defaultProps;
NavBar.displayName = 'NutNavBar';
//# sourceMappingURL=navbar.js.map