"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireDefault(require("react"));
var _reactNative = require("react-native");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const defaultPagination = props => {
  const {
    styles,
    current,
    vertical,
    count,
    dotStyle,
    dotActiveStyle
  } = props;
  const positionStyle = vertical ? 'paginationY' : 'paginationX';
  const flexDirection = vertical ? 'column' : 'row';
  const arr = [];
  for (let i = 0; i < count; i++) {
    arr.push( /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      key: `dot-${i}`,
      style: [styles.pointStyle, styles.spaceStyle, dotStyle, i === current && styles.pointActiveStyle, i === current && dotActiveStyle]
    }));
  }
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.pagination, styles[positionStyle]]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      flexDirection
    }
  }, arr));
};
class Carousel extends _react.default.PureComponent {
  static defaultProps = {
    accessibilityLabel: 'Carousel',
    pageStyle: {},
    infinite: false,
    autoplay: false,
    autoplayInterval: 3000,
    selectedIndex: 0,
    vertical: false,
    pagination: defaultPagination,
    dotStyle: {},
    dotActiveStyle: {}
  };
  scrollview = /*#__PURE__*/_react.default.createRef();
  constructor(props) {
    super(props);
    const {
      children,
      selectedIndex
    } = this.props;
    this.count = children ? _react.default.Children.count(children) : 0;
    const index = this.count > 1 && Math.min(selectedIndex, this.count - 1) || 0;
    this.state = {
      width: 0,
      height: 0,
      isScrolling: false,
      selectedIndex: index,
      afterSelectedIndex: -1,
      offset: {
        x: 0,
        y: 0
      }
    };
  }
  componentDidMount() {
    this.autoplay();
  }
  UNSAFE_componentWillReceiveProps(nextProps) {
    const {
      autoplay,
      children,
      infinite,
      vertical
    } = nextProps;
    const {
      width,
      height
    } = this.state;
    if (autoplay !== this.props.autoplay) {
      if (autoplay) {
        this.autoplay();
      } else {
        this.autoplayTimer && clearTimeout(this.autoplayTimer);
      }
    }
    if (children && _react.default.Children.count(children) === this.count && infinite === this.props.infinite) {
      return;
    }
    this.count = _react.default.Children.count(children) || 1;
    const offset = vertical ? {
      x: 0,
      y: height * (infinite ? 1 : 0)
    } : {
      x: width * (infinite ? 1 : 0),
      y: 0
    };
    this.setState({
      isScrolling: false,
      afterSelectedIndex: -1,
      selectedIndex: 0,
      offset: offset
    }, () => {
      var _this$scrollview, _this$scrollview$curr;
      (_this$scrollview = this.scrollview) === null || _this$scrollview === void 0 ? void 0 : (_this$scrollview$curr = _this$scrollview.current) === null || _this$scrollview$curr === void 0 ? void 0 : _this$scrollview$curr.scrollTo(offset);
      this.autoplay();
    });
  }
  componentWillUnmount() {
    this.autoplayTimer && clearTimeout(this.autoplayTimer);
    this.scrollEndTimter && clearTimeout(this.scrollEndTimter);
  }
  onScrollBegin = e => {
    this.setState({
      isScrolling: true
    }, () => {
      if (this.props.onScrollBeginDrag) {
        this.props.onScrollBeginDrag(e);
      }
    });
  };
  onScrollEnd = e => {
    var _e$persist;
    (_e$persist = e.persist) === null || _e$persist === void 0 ? void 0 : _e$persist.call(e);
    // android/web hack
    if (!e.nativeEvent.contentOffset) {
      //@ts-ignore
      const {
        position
      } = e.nativeEvent;
      e.nativeEvent.contentOffset = {
        x: this.props.vertical ? 0 : position * this.state.width,
        y: this.props.vertical ? position * this.state.height : 0
      };
    }
    this.autoplay();
    clearTimeout(this.scrollEndTimter);
    this.scrollEndTimter = setTimeout(() => {
      this.updateIndex(e.nativeEvent.contentOffset);
      if (this.props.onMomentumScrollEnd) {
        this.props.onMomentumScrollEnd(e);
      }
    }, 50); //idle time
  };

  onScrollEndDrag = e => {
    var _e$persist2;
    (_e$persist2 = e.persist) === null || _e$persist2 === void 0 ? void 0 : _e$persist2.call(e);
    const {
      offset,
      selectedIndex
    } = this.state;
    const previousOffset = offset;
    const newOffset = e.nativeEvent.contentOffset;
    if ((this.props.vertical ? previousOffset.y === newOffset.y : previousOffset.x === newOffset.x) && (selectedIndex === 0 || selectedIndex === this.count - 1)) {
      this.setState({
        isScrolling: false
      });
    }
    if (this.props.onScrollEndDrag) {
      this.props.onScrollEndDrag(e);
    }
  };
  onTouchStartForWeb = () => {
    this.setState({
      isScrolling: true
    });
  };
  onTouchEndForWeb = () => {
    this.autoplay();
  };
  onScrollForWeb = e => {
    this.onScrollEnd(JSON.parse(JSON.stringify(e)));
  };
  onLayout = e => {
    const {
      selectedIndex,
      infinite,
      vertical
    } = this.props;
    const scrollIndex = this.count > 1 && Math.min(selectedIndex, this.count - 1) || 0;
    const {
      width,
      height
    } = e.nativeEvent.layout;
    const offset = vertical ? {
      x: 0,
      y: height * (scrollIndex + (infinite && this.count > 1 ? 1 : 0))
    } : {
      x: width * (scrollIndex + (infinite && this.count > 1 ? 1 : 0)),
      y: 0
    };
    this.setState({
      width,
      height,
      offset
    }, () => {
      var _this$scrollview2, _this$scrollview2$cur;
      // web
      (_this$scrollview2 = this.scrollview) === null || _this$scrollview2 === void 0 ? void 0 : (_this$scrollview2$cur = _this$scrollview2.current) === null || _this$scrollview2$cur === void 0 ? void 0 : _this$scrollview2$cur.scrollTo({
        ...offset,
        animated: false
      });
      this.autoplay();
    });
  };
  updateIndex = currentOffset => {
    const paramOffset = currentOffset;
    let {
      selectedIndex
    } = this.state;
    const {
      offset,
      width,
      height
    } = this.state;
    const diff = this.props.vertical ? paramOffset.y - offset.y : paramOffset.x - offset.x;
    if (!diff) {
      return;
    }
    selectedIndex += Math.round(diff / (this.props.vertical ? height : width));
    if (this.props.infinite) {
      if (selectedIndex <= -1) {
        selectedIndex = this.count - 1;
        if (this.props.vertical) {
          paramOffset.y = height * this.count;
        } else {
          paramOffset.x = width * this.count;
        }
      } else if (selectedIndex >= this.count) {
        selectedIndex = 0;
        if (this.props.vertical) {
          paramOffset.y = height;
        } else {
          paramOffset.x = width;
        }
      }
      if (this.props.vertical) {
        if (paramOffset.y === height) {
          this.scrollToStart();
        } else if (paramOffset.y === this.count * height) {
          this.scrollToEnd();
        }
      } else {
        if (paramOffset.x === width) {
          this.scrollToStart();
        } else if (paramOffset.x === this.count * width) {
          this.scrollToEnd();
        }
      }
    }
    this.setState({
      selectedIndex,
      offset: paramOffset
    }, () => {
      if (this.props.afterChange && this.state.selectedIndex !== this.state.afterSelectedIndex) {
        this.setState({
          afterSelectedIndex: selectedIndex
        }, () => {
          var _this$props$afterChan, _this$props;
          (_this$props$afterChan = (_this$props = this.props).afterChange) === null || _this$props$afterChan === void 0 ? void 0 : _this$props$afterChan.call(_this$props, selectedIndex);
        });
      }
    });
  };
  scrollToStart = () => {
    var _this$scrollview3, _this$scrollview3$cur;
    (_this$scrollview3 = this.scrollview) === null || _this$scrollview3 === void 0 ? void 0 : (_this$scrollview3$cur = _this$scrollview3.current) === null || _this$scrollview3$cur === void 0 ? void 0 : _this$scrollview3$cur.scrollTo({
      x: this.props.vertical ? 0 : this.state.width,
      y: this.props.vertical ? this.state.height : 0,
      animated: false
    });
  };
  scrollToEnd = () => {
    var _this$scrollview4, _this$scrollview4$cur;
    (_this$scrollview4 = this.scrollview) === null || _this$scrollview4 === void 0 ? void 0 : (_this$scrollview4$cur = _this$scrollview4.current) === null || _this$scrollview4$cur === void 0 ? void 0 : _this$scrollview4$cur.scrollTo({
      x: this.props.vertical ? 0 : this.state.width * this.count,
      y: this.props.vertical ? this.state.height * this.count : 0,
      animated: false
    });
  };
  scrollNextPage = () => {
    var _this$scrollview5, _this$scrollview5$cur;
    const {
      selectedIndex,
      isScrolling,
      width,
      height
    } = this.state;
    if (isScrolling || this.count < 2) {
      return;
    }
    const diff = selectedIndex + 1 + (this.props.infinite ? 1 : 0);
    (_this$scrollview5 = this.scrollview) === null || _this$scrollview5 === void 0 ? void 0 : (_this$scrollview5$cur = _this$scrollview5.current) === null || _this$scrollview5$cur === void 0 ? void 0 : _this$scrollview5$cur.scrollTo(this.props.vertical ? {
      x: 0,
      y: diff * height
    } : {
      x: diff * width,
      y: 0
    });
    this.setState({
      isScrolling: true
    }, () => {
      if (_reactNative.Platform.OS !== 'ios') {
        this.onScrollEnd({
          nativeEvent: {
            // @ts-ignore
            position: diff
          }
        });
      }
    });
  };

  /**
   * go to index
   * @param index
   * @param animated
   */
  goTo(index, animated) {
    var _this$scrollview6, _this$scrollview6$cur;
    const {
      width,
      height
    } = this.state;
    const count = this.props.infinite ? this.count - 1 : this.count;
    if (typeof index !== 'number' || index < 0 || index > count) {
      return;
    }
    (_this$scrollview6 = this.scrollview) === null || _this$scrollview6 === void 0 ? void 0 : (_this$scrollview6$cur = _this$scrollview6.current) === null || _this$scrollview6$cur === void 0 ? void 0 : _this$scrollview6$cur.scrollTo({
      x: this.props.vertical ? 0 : (index + (this.props.infinite ? 1 : 0)) * width,
      y: this.props.vertical ? (index + (this.props.infinite ? 1 : 0)) * height : 0,
      animated
    });
  }
  render() {
    const {
      children,
      infinite,
      accessibilityLabel,
      pageStyle
    } = this.props;
    const {
      width,
      height,
      selectedIndex
    } = this.state;
    if (!children) {
      return null;
    }
    let pages;
    const pageWidth = [pageStyle, {
      width,
      height
    }];
    if (this.count > 1) {
      const childrenArray = _react.default.Children.toArray(children);
      if (infinite) {
        childrenArray.unshift(childrenArray[this.count - 1]);
        childrenArray.push(childrenArray[1]);
      }
      pages = childrenArray.map((child, index) => /*#__PURE__*/_react.default.createElement(_reactNative.View, {
        key: `carousel_${index}`,
        accessibilityLabel: `${accessibilityLabel}_${index}`,
        style: pageWidth
      }, child));
    } else {
      pages = /*#__PURE__*/_react.default.createElement(_reactNative.View, {
        style: pageWidth
      }, children);
    }
    return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      onLayout: this.onLayout
    }, this.renderScroll(pages));
  }
  autoplay = () => {
    this.setState({
      isScrolling: false
    }, () => {
      const {
        children,
        autoplay,
        autoplayInterval,
        infinite
      } = this.props;
      const {
        selectedIndex
      } = this.state;
      if (!Array.isArray(children) || !autoplay) {
        return;
      }
      clearTimeout(this.autoplayTimer);
      this.autoplayTimer = setTimeout(() => {
        if (!infinite && selectedIndex + 1 === this.count - 1) {
          return;
        }
        this.scrollNextPage();
      }, autoplayInterval);
    });
  };
  renderScroll = pages => {
    return /*#__PURE__*/_react.default.createElement(_reactNative.ScrollView, _extends({}, this.props, {
      horizontal: !this.props.vertical,
      ref: this.scrollview,
      showsHorizontalScrollIndicator: false,
      showsVerticalScrollIndicator: false,
      pagingEnabled: true,
      removeClippedSubviews: false,
      automaticallyAdjustContentInsets: false,
      directionalLockEnabled: true,
      contentOffset: this.state.offset,
      onScrollBeginDrag: this.onScrollBegin,
      onMomentumScrollEnd: this.onScrollEnd,
      onScrollEndDrag: this.onScrollEndDrag
    }, _reactNative.Platform.OS === 'web' ? {
      onTouchStart: this.onTouchStartForWeb,
      onTouchEnd: this.onTouchEndForWeb,
      onScroll: this.onScrollForWeb,
      scrollEventThrottle: 0
    } : {}), pages);
  };
}
var _default = Carousel;
exports.default = _default;
//# sourceMappingURL=carousel.js.map