"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Price = void 0;
var _react = _interopRequireDefault(require("react"));
var _reactNative = require("react-native");
var _styleToObj = _interopRequireDefault(require("../utils/style-to-obj"));
var _filterContainerStyle = _interopRequireDefault(require("../utils/filter-container-style"));
var _filterTextStyle = _interopRequireDefault(require("../utils/filter-text-style"));
var _pt = _interopRequireDefault(require("../utils/pt"));
var _configprovider = require("../configprovider");
var _styles = _interopRequireDefault(require("./styles"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
// 按钮大小

const defaultProps = {
  price: 0,
  needSymbol: true,
  symbol: '&yen;',
  decimalDigits: 2,
  thousands: false,
  position: 'before',
  size: 'large'
};
const Price = props => {
  const {
    price,
    needSymbol,
    symbol,
    decimalDigits,
    thousands,
    style,
    position,
    size
  } = {
    ...defaultProps,
    ...props
  };
  const {
    theme
  } = (0, _configprovider.useConfig)();
  const styles = (0, _styles.default)(theme);
  const replaceSpecialChar = symbol => {
    let desSymbol = symbol;
    desSymbol = symbol.replace(/&quot;/g, '"');
    desSymbol = symbol.replace(/&amp;/g, '&');
    desSymbol = symbol.replace(/&lt;/g, '<');
    desSymbol = symbol.replace(/&gt;/g, '>');
    desSymbol = symbol.replace(/&nbsp;/g, ' ');
    desSymbol = symbol.replace(/&yen;/g, '￥');
    return desSymbol;
  };
  const checkPoint = price => {
    return String(price).indexOf('.') > 0;
  };
  const formatThousands = num => {
    if (Number(num) === 0) {
      num = 0;
    }
    if (checkPoint(num)) {
      num = Number(num).toFixed(decimalDigits);
      num = typeof num.split('.') === 'string' ? num.split('.') : num.split('.')[0];
    } else {
      num = num.toString();
    }
    if (thousands) {
      return (num || 0).toString().replace(/(\d)(?=(?:\d{3})+$)/g, '$1,');
    }
    return num;
  };
  const formatDecimal = decimalNum => {
    if (Number(decimalNum) === 0) {
      decimalNum = 0;
    }
    if (checkPoint(decimalNum)) {
      decimalNum = Number(decimalNum).toFixed(decimalDigits);
      decimalNum = typeof decimalNum.split('.') === 'string' ? 0 : decimalNum.split('.')[1];
    } else {
      decimalNum = 0;
    }
    const result = `0.${decimalNum}`;
    const resultFixed = Number(result).toFixed(decimalDigits);
    return String(resultFixed).substring(2, resultFixed.length);
  };
  const wrapStyle = [styles.container, (0, _filterContainerStyle.default)((0, _styleToObj.default)(style || {}))];
  const symbolStyle = [styles.defaultText, (0, _filterTextStyle.default)((0, _styleToObj.default)(style || {})), {
    marginTop: (0, _pt.default)(2)
  }, styles[`symbol${size}`]];
  const bigStyle = [styles.defaultText, size === 'large' ? {
    marginTop: -(0, _pt.default)(6)
  } : {}, (0, _filterTextStyle.default)((0, _styleToObj.default)(style || {})), styles[`big${size}`]];
  const pointStyle = [styles.defaultText, size === 'large' ? {
    marginTop: -(0, _pt.default)(4)
  } : {}, size === 'small' ? {
    marginTop: -(0, _pt.default)(6)
  } : {}, (0, _filterTextStyle.default)((0, _styleToObj.default)(style || {})), styles[`point${size}`]];
  const smallStyle = [styles.defaultText, (0, _filterTextStyle.default)((0, _styleToObj.default)(style || {})), styles[`small${size}`]];
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: wrapStyle
  }, position === 'before' && needSymbol ? /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: symbolStyle
  }, replaceSpecialChar(symbol)) : null, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: bigStyle
  }, formatThousands(price)), decimalDigits ? /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: pointStyle
  }, ".") : null, decimalDigits ? /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: smallStyle
  }, formatDecimal(price)) : null, position === 'after' && needSymbol ? /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: symbolStyle
  }, replaceSpecialChar(symbol)) : null);
};
exports.Price = Price;
Price.defaultProps = defaultProps;
Price.displayName = 'NutPrice';
//# sourceMappingURL=price.js.map