"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Radio = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _context = _interopRequireDefault(require("./context"));
var _radiogroup = _interopRequireDefault(require("../radiogroup"));
var _index = _interopRequireDefault(require("../icon/index"));
var _styleToObj = _interopRequireDefault(require("../utils/style-to-obj"));
var _filterContainerStyle = _interopRequireDefault(require("../utils/filter-container-style"));
var _filterTextStyle = _interopRequireDefault(require("../utils/filter-text-style"));
var _configprovider = require("../configprovider");
var _styles = _interopRequireDefault(require("./styles"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const defaultProps = {
  disabled: false,
  checked: false,
  shape: 'round',
  value: '',
  textPosition: 'right',
  iconName: 'check-normal',
  iconActiveName: 'check-checked',
  iconSize: 18,
  onChange: e => {}
};
const Radio = props => {
  const {
    children
  } = {
    ...defaultProps,
    ...props
  };
  const {
    disabled,
    checked,
    shape,
    textPosition,
    value,
    iconName,
    iconActiveName,
    iconSize,
    onChange,
    style
  } = props;
  const context = (0, _react.useContext)(_context.default);
  const {
    theme
  } = (0, _configprovider.useConfig)();
  const styles = (0, _styles.default)(theme);
  const onPressCallback = (0, _react.useCallback)(e => {
    if (disabled || checked) return;
    onChange && onChange(e);
    context && context.onChange(value);
  }, [disabled, checked]);
  const wrapStyle = [styles[`shape${shape}Container`], styles[`${shape}Checked${checked}`], (0, _filterContainerStyle.default)((0, _styleToObj.default)(style || {})), styles[`${shape}Disabled${disabled}`]];
  const textStyle = [styles[`textDefault${shape}`], (0, _filterTextStyle.default)((0, _styleToObj.default)(style || {})), styles[`textChecked${shape}${checked}`], styles[`textPosition${textPosition}`]];
  const renderRound = () => {
    if (textPosition === 'left') {
      return [/*#__PURE__*/_react.default.createElement(_reactNative.Text, {
        key: 1,
        style: textStyle
      }, children), /*#__PURE__*/_react.default.createElement(_index.default, {
        key: 2,
        name: checked ? iconActiveName : iconName,
        size: iconSize,
        color: checked ? '#f0250f' : '#d6d6d6'
      })];
    }
    return [/*#__PURE__*/_react.default.createElement(_index.default, {
      key: 1,
      name: checked ? iconActiveName : iconName,
      size: iconSize,
      color: checked ? '#f0250f' : '#d6d6d6',
      style: styles.mr10
    }), /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
      key: 2,
      style: textStyle
    }, children)];
  };
  const renderButton = () => {
    return /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
      style: textStyle
    }, children);
  };
  if (disabled) {
    return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: wrapStyle
    }, shape === 'round' ? renderRound() : renderButton());
  }
  return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableHighlight, {
    underlayColor: null,
    activeOpacity: 1,
    onPress: onPressCallback
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: wrapStyle
  }, shape === 'round' ? renderRound() : renderButton()));
};
exports.Radio = Radio;
Radio.defaultProps = defaultProps;
Radio.displayName = 'NutRadio';
Radio.RadioGroup = _radiogroup.default;
//# sourceMappingURL=radio.js.map