"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TextArea = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _configprovider = require("../configprovider");
var _input = _interopRequireDefault(require("../input"));
var _styles = _interopRequireDefault(require("./styles"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const defaultProps = {
  defaultValue: '',
  textAlign: 'left',
  limitshow: false,
  maxlength: '',
  rows: '2',
  placeholder: '',
  readonly: false,
  disabled: false,
  autosize: false
};
const TextArea = props => {
  const {
    locale,
    theme
  } = (0, _configprovider.useConfig)();
  const styles = (0, _styles.default)(theme);
  const {
    defaultValue,
    textAlign,
    limitshow,
    maxlength,
    rows,
    placeholder,
    readonly,
    disabled,
    autosize,
    style,
    onChange,
    onBlur,
    onFocus
  } = {
    ...defaultProps,
    ...props
  };

  //   const textareaBem = bem('textarea')
  const [inputValue, SetInputValue] = (0, _react.useState)('');
  const textareaRef = (0, _react.useRef)(null);
  (0, _react.useEffect)(() => {
    let initValue = defaultValue;
    if (initValue && maxlength && [...initValue].length > Number(maxlength)) {
      initValue = initValue.substring(0, Number(maxlength));
    }
    SetInputValue(initValue);
    if (autosize) {
      setTimeout(() => {
        setContentHeight();
      });
    }
  }, [defaultValue, autosize]);
  (0, _react.useEffect)(() => {
    if (inputValue) {
      if (autosize) {
        setContentHeight();
      }
    }
  }, [inputValue]);
  const setContentHeight = () => {
    const textarea = textareaRef.current;
    if (textarea) {
      textarea.setNativeProps({
        style: {
          height: 'auto'
        }
      });
    }
  };
  const textChange = (value, event) => {
    console.log(value);
    if (maxlength && [...value].length > Number(maxlength)) {
      value = value.substring(0, Number(maxlength));
    }
    SetInputValue(value);
    onChange && onChange(value, event);
  };
  const textFocus = event => {
    if (disabled) return;
    if (readonly) return;
    onFocus && onFocus(event);
  };
  const textBlur = (value, event) => {
    if (disabled) return;
    if (readonly) return;
    onChange && onChange(value, event);
    onBlur && onBlur(event);
  };
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.nutTextarea, disabled && styles.nutTextarea__disabled]
  }, /*#__PURE__*/_react.default.createElement(_input.default, {
    type: 'textarea',
    ref: textareaRef,
    style: {
      ...styles.nutTextarea__textarea,
      ...style
    },
    inputAlign: textAlign,
    showWordLimit: limitshow,
    disabled: disabled,
    readonly: readonly,
    defaultValue: inputValue,
    onChange: (value, e) => {
      textChange(value, e);
    },
    onBlur: (value, e) => {
      textBlur(value, e);
    },
    onFocus: e => {
      textFocus(e);
    },
    rows: rows,
    maxlength: maxlength < 0 ? 0 : maxlength,
    placeholder: placeholder || locale.placeholder
  }));
};
exports.TextArea = TextArea;
TextArea.defaultProps = defaultProps;
TextArea.displayName = 'NutTextArea';
//# sourceMappingURL=textarea.js.map