"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TimeSelect = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _popup = _interopRequireDefault(require("../popup"));
var _index = _interopRequireDefault(require("../timepannel/index"));
var _index2 = _interopRequireDefault(require("../timedetail/index"));
var _deviceWidth = _interopRequireDefault(require("../utils/deviceWidth"));
var _configprovider = require("../configprovider");
var _styles = _interopRequireDefault(require("./styles"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const defaultProps = {
  style: {},
  visible: false,
  height: '20%',
  multiple: false,
  currentKey: 0,
  currentTime: [],
  title: '取件时间',
  dates: [],
  times: []
};
const TimeSelect = props => {
  const {
    visible,
    height,
    title,
    currentKey,
    currentTime,
    dates,
    times,
    multiple,
    select,
    pannelChange,
    timeChange,
    onSelect,
    onPannelChange,
    onTimeChange
  } = {
    ...defaultProps,
    ...props
  };
  const {
    theme
  } = (0, _configprovider.useConfig)();
  const mStyles = (0, _styles.default)(theme);
  const [activeKey, setActiveKey] = (0, _react.useState)(currentKey);
  const [activeTime, setActiveTime] = (0, _react.useState)(currentTime.length ? currentTime : [{
    key: currentKey,
    list: []
  }]);
  const [popVisible, setPopVisible] = (0, _react.useState)(visible);
  const popStyle = {
    width: '100%',
    height,
    backgroundColor: '#fff'
  };

  // popup 的关闭回调, 执行 select 函数更改外部 visible
  const closeFun = () => {
    if (onSelect) {
      onSelect(activeTime);
    } else if (select) {
      select(activeTime);
    }
  };
  // 选择配送时间回调
  const handleSelectTime = time => {
    let curTimeData = {};
    let curIndex = -1;
    for (let i = 0; i < activeTime.length; i++) {
      if (String(activeTime[i].key) === String(activeKey)) {
        curTimeData = activeTime[i];
        curIndex = i;
        break;
      }
    }
    const curTimeIndex = curTimeData.list.findIndex(item => String(item) === String(time));
    if (curTimeIndex === -1) {
      curTimeData.list.push(time);
    } else {
      curTimeData.list.splice(curTimeIndex, 1);
    }
    const resultTimeData = [...activeTime];
    resultTimeData.splice(curIndex, 1, curTimeData);
    setActiveTime(resultTimeData);
    if (onTimeChange) {
      onTimeChange(time, resultTimeData);
    } else if (timeChange) {
      timeChange(time, resultTimeData);
    }
  };
  // 选择日期的回调
  const handleChange = pannelKey => {
    const resultTimeData = [...activeTime];
    if (String(pannelKey) !== String(activeKey)) {
      setActiveKey === null || setActiveKey === void 0 ? void 0 : setActiveKey(pannelKey);
      if (multiple) {
        const curTimeDataIndex = activeTime.findIndex(item => String(item.key) === String(pannelKey));
        if (curTimeDataIndex === -1) {
          resultTimeData.push({
            key: pannelKey,
            list: []
          });
          setActiveTime(resultTimeData);
        }
      } else {
        setActiveTime([{
          key: pannelKey,
          list: []
        }]);
      }
    }
    if (onPannelChange) {
      onPannelChange(pannelKey, resultTimeData);
    } else if (pannelChange) {
      pannelChange(pannelKey, resultTimeData);
    }
  };
  // 选中的日期增加 active 类名
  const getTimePannelClass = dataItem => {
    if (String(dataItem['pannel-key']) === String(activeKey)) {
      return 'active';
    }
    return 'noactive';
  };
  // 根据外部传入 visible 进行组件的显隐展示
  (0, _react.useEffect)(() => {
    setPopVisible(visible);
  }, [visible]);
  return /*#__PURE__*/_react.default.createElement(_popup.default, {
    closeable: true,
    round: true,
    closeOnClickOverlay: true,
    visible: popVisible,
    position: "bottom",
    style: popStyle,
    onClose: () => {
      closeFun();
    },
    onClickCloseIcon: () => {
      closeFun();
    }
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: mStyles.nut_timeselect_container
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: mStyles.nut_timeselect_title
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, null, title)), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      flexDirection: 'row'
    }
  }, /*#__PURE__*/_react.default.createElement(_reactNative.ScrollView, {
    style: {
      width: _deviceWidth.default * 2 / 5
    }
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, null, dates.map((dataItem, index) => /*#__PURE__*/_react.default.createElement(_index.default, {
    date: dataItem.date,
    className: getTimePannelClass(dataItem),
    key: String(dataItem['pannel-key'] || index),
    curKey: String(dataItem['pannel-key'] || index),
    change: handleChange
  })))), /*#__PURE__*/_react.default.createElement(_reactNative.ScrollView, {
    style: {
      width: _deviceWidth.default * 3 / 5
    }
  }, /*#__PURE__*/_react.default.createElement(_index2.default, {
    times: times,
    currentKey: String(activeKey),
    currentTime: activeTime,
    select: handleSelectTime
  })))));
};
exports.TimeSelect = TimeSelect;
TimeSelect.defaultProps = defaultProps;
TimeSelect.displayName = 'NutTimeSelect';
//# sourceMappingURL=timeselect.js.map