import React from 'react';
import { View, Text, TouchableHighlight } from 'react-native';
import Icon from '../icon';
import fConStyle from '../utils/filter-container-style';
import toObj from '../utils/style-to-obj';
import { useConfig } from '../configprovider';
import cellStyles from './styles';
const defaultProps = {
  title: null,
  subTitle: null,
  desc: '',
  descTextAlign: 'right',
  isLink: false,
  icon: '',
  roundRadius: 6,
  // url: '',
  // to: '',
  // replace: false,
  center: false,
  size: '',
  iconSlot: null,
  linkSlot: null,
  cellGroup: false,
  isLast: false
};
export const Cell = props => {
  const {
    children,
    onClick,
    title,
    subTitle,
    desc,
    descTextAlign,
    isLink,
    icon,
    roundRadius,
    center,
    size,
    iconSlot,
    linkSlot,
    cellGroup,
    isLast,
    style
  } = {
    ...defaultProps,
    ...props
  };
  const {
    theme
  } = useConfig();
  const styles = cellStyles(theme);
  const handleClick = event => {
    onClick && onClick(event);
  };
  const baseStyle = {
    borderRadius: roundRadius
  };
  const tTextStyle = [styles.tText, styles[`tTextSize${size}`]];
  const subTextStyle = [styles.subText, styles[`subTextSize${size}`]];
  const descCStyle = [styles.descC, center ? {
    alignSelf: 'center'
  } : {}, title || subTitle || icon ? {} : {
    textAlign: descTextAlign,
    flex: 1
  }];
  const descTextStyle = [styles.descText, styles[`descAlone${!title && !subTitle}`], styles[`descSize${size}`]];
  const innerStyle = [styles.innerStyle, styles[`innerCenter${center}`], fConStyle(toObj(style || {}))];
  const renderComponent = () => {
    if (children) {
      return children;
    }
    return /*#__PURE__*/React.createElement(View, {
      style: innerStyle
    }, /*#__PURE__*/React.createElement(React.Fragment, null, iconSlot || null, icon ? /*#__PURE__*/React.createElement(Icon, {
      name: icon,
      style: styles.icon,
      size: 18
    }) : null, title || subTitle ? /*#__PURE__*/React.createElement(View, {
      style: styles.titleContainer
    }, title ? /*#__PURE__*/React.createElement(Text, {
      style: tTextStyle
    }, title) : null, subTitle ? /*#__PURE__*/React.createElement(Text, {
      style: subTextStyle
    }, subTitle) : null) : null), /*#__PURE__*/React.createElement(React.Fragment, null, desc ? /*#__PURE__*/React.createElement(View, {
      style: descCStyle
    }, /*#__PURE__*/React.createElement(Text, {
      style: descTextStyle
    }, desc)) : null, !linkSlot && isLink ? /*#__PURE__*/React.createElement(Icon, {
      name: "right",
      color: "#979797",
      size: 14
    }) : /*#__PURE__*/React.createElement(View, null, linkSlot)));
  };
  const wrapStyle = [styles.container, styles[`container${size}`], styles[`containerCellGroup${cellGroup}`], styles[`containerIsLast${isLast}`], baseStyle];
  if (isLink) {
    return /*#__PURE__*/React.createElement(TouchableHighlight, {
      style: [baseStyle, {
        width: '100%'
      }],
      activeOpacity: 1,
      underlayColor: null,
      onPress: handleClick
    }, /*#__PURE__*/React.createElement(View, {
      style: wrapStyle
    }, renderComponent()));
  }
  if (onClick) {
    return /*#__PURE__*/React.createElement(TouchableHighlight, {
      style: [baseStyle, {
        width: '100%'
      }],
      activeOpacity: 1,
      underlayColor: null,
      onPress: onClick
    }, /*#__PURE__*/React.createElement(View, {
      style: wrapStyle
    }, renderComponent()));
  }
  return /*#__PURE__*/React.createElement(View, {
    style: wrapStyle
  }, renderComponent());
};
Cell.defaultProps = defaultProps;
Cell.displayName = 'NutCell';
//# sourceMappingURL=cell.js.map