import React, { useEffect, useState } from 'react';
import { View, Text, TouchableOpacity, Animated } from 'react-native';
import Icon from '../icon';
import { ComponentDefaults } from '../utils/typings';
import { useConfig } from '../configprovider';
import collapseStyles from './styles';
import pt from '../utils/pt';
const defaultProps = {
  ...ComponentDefaults,
  title: '',
  name: '',
  isOpen: false,
  icon: '',
  iconSize: '',
  iconColor: '',
  disabled: false,
  rotate: 180,
  subTitle: '',
  titleIcon: '',
  titleIconColor: '',
  titleIconPosition: '',
  titleIconSize: '',
  childnull: true
};
export const CollapseItem = props => {
  const {
    children,
    title,
    isOpen,
    onToggle,
    name,
    disabled,
    icon,
    rotate,
    subTitle,
    titleIcon,
    titleIconColor,
    titleIconPosition,
    titleIconSize,
    iconSize,
    iconColor,
    childnull,
    iconClassPrefix,
    iconFontClassName
  } = {
    ...defaultProps,
    ...props
  };
  const {
    theme
  } = useConfig();
  const styles = collapseStyles(theme);
  const [currHeight, setCurrHeight] = useState('auto'); // 设置content的高度
  const [iconStyle, setIconStyle] = useState({
    transform: [{
      translateY: -pt(20)
    }]
  });
  useEffect(() => {
    // 一开始content都有高度，在这里根据isOpen，改变其高度
    setTimeout(() => {
      const newIconStyle = isOpen ? {
        transform: [{
          translateY: -pt(20)
        }, {
          rotate: `${rotate}deg`
        }]
      } : {
        transform: [{
          translateY: -pt(20)
        }]
      };
      setIconStyle(newIconStyle);
    }, 10);
  }, [isOpen, rotate]);
  useEffect(() => {
    if (!isOpen) {
      setCurrHeight(0);
    } else {
      setCurrHeight('auto');
    }
  }, [children, isOpen]);
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(TouchableOpacity, {
    style: [styles.collapseItem__header, styles.borderBt],
    onPress: () => {
      if (disabled) return;
      onToggle === null || onToggle === void 0 ? void 0 : onToggle(isOpen, name);
    }
  }, /*#__PURE__*/React.createElement(View, {
    style: styles.collapseItem__title
  }, !!titleIcon && titleIconPosition === 'left' && /*#__PURE__*/React.createElement(View, {
    style: styles.collapseItem__titleIconLeft
  }, /*#__PURE__*/React.createElement(Icon, {
    classPrefix: iconClassPrefix,
    fontClassName: iconFontClassName,
    name: titleIcon,
    size: titleIconSize,
    color: disabled ? '#C2C2C2' : titleIconColor
  })), /*#__PURE__*/React.createElement(Text, {
    style: [styles.collapseItem__title__text, disabled && styles.collapseItem__title__disable]
  }, title), !!titleIcon && titleIconPosition === 'right' && /*#__PURE__*/React.createElement(View, {
    style: styles.collapseItem__titleIconRight
  }, /*#__PURE__*/React.createElement(Icon, {
    classPrefix: iconClassPrefix,
    fontClassName: iconFontClassName,
    name: titleIcon,
    size: titleIconSize,
    color: disabled ? '#C2C2C2' : titleIconColor
  }))), /*#__PURE__*/React.createElement(Text, {
    style: styles.collapseItem__subTitle,
    numberOfLines: 1
  }, subTitle), /*#__PURE__*/React.createElement(View, {
    style: styles.collapseItem__iconBox
  }, /*#__PURE__*/React.createElement(Animated.View, {
    style: [styles.collapseItem__icon, iconStyle]
  }, /*#__PURE__*/React.createElement(Icon, {
    classPrefix: iconClassPrefix,
    fontClassName: iconFontClassName,
    name: icon,
    size: iconSize,
    color: disabled ? '#C2C2C2' : iconColor
  })))), childnull && /*#__PURE__*/React.createElement(View, {
    style: [styles.collapseItem__content, {
      height: currHeight
    }]
  }, /*#__PURE__*/React.createElement(View, {
    style: styles.collapseItem__contentText
  }, typeof children === 'string' ? /*#__PURE__*/React.createElement(Text, null, children) : children)));
};
CollapseItem.defaultProps = defaultProps;
CollapseItem.displayName = 'NutCollapseItem';
//# sourceMappingURL=collapseitem.js.map