import React from 'react';
import { View, Text } from 'react-native';
import toObj from '../utils/style-to-obj';
import fConStyleNoBorder from '../utils/filter-container-style-without-border';
import fBorStyle from '../utils/filter-border-style';
import fTexStyle from '../utils/filter-text-style';
import { useConfig } from '../configprovider';
import dividerStyles from './styles';
const defaultProps = {
  contentPosition: 'center',
  // 内容位置，可选值为left right
  dashed: false,
  // 是否使用虚线
  hairline: true,
  // 是否使用 0.5px 线, RN 0.5有兼容性问题
  direction: 'horizontal' // 水平还是垂直类型
};

const renderChilden = (children, styles, contentPosition, dashed, hairline, myStyles) => {
  const Component = typeof children === 'string' ? /*#__PURE__*/React.createElement(Text, {
    key: 2,
    style: [myStyles.text, fTexStyle(toObj(styles))]
  }, children) : children;
  return [/*#__PURE__*/React.createElement(View, {
    key: 1,
    style: [myStyles[`left${contentPosition}`], myStyles[`lineStyle${dashed}`], myStyles[`lineWidth${hairline}`], fBorStyle(toObj(styles))]
  }), Component, /*#__PURE__*/React.createElement(View, {
    key: 3,
    style: [myStyles[`right${contentPosition}`], myStyles[`lineStyle${dashed}`], myStyles[`lineWidth${hairline}`], fBorStyle(toObj(styles))]
  })];
};
export const Divider = props => {
  const {
    children,
    contentPosition,
    dashed,
    hairline,
    direction,
    styles
  } = {
    ...defaultProps,
    ...props
  };
  const {
    theme
  } = useConfig();
  const myStyles = dividerStyles(theme);
  let wrapStyle;
  if (direction === 'vertical') {
    wrapStyle = [myStyles.verticalStyle, toObj(styles || {})];
  } else {
    wrapStyle = [myStyles[`row${!!children}Style`], myStyles[`dashed${dashed}${!!children}`] || {}, myStyles[`hairline${dashed}${hairline}${!!children}`] || {}, !children ? toObj(styles || {}) : {} // 没有子元素或将props 样式传递
    ];
  }

  if (!children) {
    return /*#__PURE__*/React.createElement(View, {
      style: wrapStyle
    });
  }
  return /*#__PURE__*/React.createElement(View, {
    style: [wrapStyle, fConStyleNoBorder(toObj(styles || {}))]
  }, renderChilden(children, styles, contentPosition, dashed, hairline, myStyles));
};
Divider.displayName = 'NutDivider';
//# sourceMappingURL=divider.js.map