function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React, { useRef, useState, createContext } from 'react';
import { View, Text, PanResponder, TouchableOpacity, NativeModules, findNodeHandle, FlatList } from 'react-native';
import { animated } from '@react-spring/native';
import { useConfig } from '../configprovider';
import elevatorStyles from './styles';
export const elevatorContext = /*#__PURE__*/createContext({});
const defaultProps = {
  height: 200,
  acceptKey: 'title',
  indexList: [],
  isSticky: false,
  spaceHeight: 23,
  titleHeight: 35
};
export const Elevator = props => {
  const {
    height,
    acceptKey,
    indexList,
    isSticky,
    spaceHeight,
    titleHeight,
    style,
    onClickItem,
    onClickIndex,
    children
  } = {
    ...defaultProps,
    ...props
  };
  const {
    theme
  } = useConfig();
  const styles = elevatorStyles(theme);
  const listview = useRef(null);
  const listHeight = useRef([]);
  const [scrollY, setScrollY] = useState(0);
  const [barTop, setBarTop] = useState(0);
  const [currentData, setCurrentData] = useState({});
  const [currentKey, setCurrentKey] = useState('');
  const [codeIndex, setCodeIndex] = useState(0);
  const [scrollStart, setScrollStart] = useState(false);
  const panResponder = PanResponder.create({
    onStartShouldSetPanResponder: () => false,
    onStartShouldSetPanResponderCapture: () => false,
    onMoveShouldSetPanResponderCapture: () => true,
    onPanResponderTerminationRequest: () => false,
    // 这个很重要，这边不放权
    onShouldBlockNativeResponder: () => false,
    onMoveShouldSetPanResponder: (evt, g) => {
      // 解决PanResponder中的onPress无作用
      // 当大于5时才进入移动事件，有的情况下需要将onStartShouldSetPanResponderCapture设为false
      if (Math.abs(g.dx) > 5 || Math.abs(g.dy) > 5) {
        return true;
      } else if (Math.abs(g.dx) <= 5 || Math.abs(g.dy) <= 5) {
        return false;
      }
      return false;
    },
    // onPanResponderGrant: (e, gesture) => {
    //   console.log('onPanResponderGrant', e.nativeEvent, gesture);
    // },
    onPanResponderMove: (e, gesture) => {
      //   const padding = theme['$elevator-list-item-bars-padding'];

      let index = Math.ceil((gesture.moveY - barTop) / spaceHeight);
      if (index >= indexList.length - 1) {
        index = indexList.length - 1;
      }
      if (index <= 0) {
        index = 0;
      }
      setCodeIndex(index);
      scrollTo(index);
      setScrollStart(true);
    },
    onPanResponderRelease: () => {
      setScrollStart(false);
    }
  });

  // 获取距离屏幕顶高度
  const getBarInfo = e => {
    const handle = findNodeHandle(e.target);
    NativeModules.UIManager.measure(handle, (x0, y0, width, height, x, py) => {
      setBarTop(py);
    });
  };
  const getItemsInfo = (e, index) => {
    const {
      height
    } = e.nativeEvent.layout;
    listHeight.current[index] = height;
  };
  const scrollTo = index => {
    if (!index && index !== 0) {
      return;
    }
    if (listview.current) {
      listview.current.scrollToIndex({
        index: index,
        animated: false
      });
    }
  };
  const handleClickItem = (key, item) => {
    onClickItem === null || onClickItem === void 0 ? void 0 : onClickItem(key, item);
    setCurrentData(item);
    setCurrentKey(key);
  };
  const handleClickIndex = (key, index) => {
    setCurrentKey(key);
    setCodeIndex(index);
    scrollTo(index);
    setScrollStart(true);
    setTimeout(() => {
      setScrollStart(false);
    }, 1000);
    onClickIndex === null || onClickIndex === void 0 ? void 0 : onClickIndex(key);
  };
  const onScroll = e => {
    setScrollY(e.nativeEvent.contentOffset.y);
    listHeight.current.reduce((top, height, index) => {
      if (scrollY > top) {
        setCodeIndex(index);
      }
      return top + height;
    }, 0);
  };
  const renderItem = _ref => {
    let {
      item,
      index
    } = _ref;
    return /*#__PURE__*/React.createElement(View, {
      style: styles.elevatorList__item,
      key: item[acceptKey],
      onLayout: e => getItemsInfo(e, index)
    }, /*#__PURE__*/React.createElement(View, {
      style: [styles.elevatorList__item__code, {
        height: titleHeight
      }]
    }, /*#__PURE__*/React.createElement(Text, {
      style: styles.elevatorList__item__codeText
    }, item[acceptKey])), item.list.map(subitem => {
      const activeText = currentData.id === subitem.id && currentKey === item[acceptKey] ? styles.elevatorList__item__nameHightcolor : {};
      return /*#__PURE__*/React.createElement(TouchableOpacity, {
        style: styles.elevatorList__item__name,
        key: subitem.id,
        onPress: () => handleClickItem(item[acceptKey], subitem)
      }, children ? /*#__PURE__*/React.createElement(elevatorContext.Provider, {
        value: subitem
      }, children) : /*#__PURE__*/React.createElement(Text, {
        style: [styles.elevatorList__item__nameText, activeText]
      }, subitem.name));
    }));
  };
  const transformBar = [{
    translateY: -(spaceHeight * indexList.length) / 2
  }] || theme['$elevator-list-item-code-current-transform'];
  return /*#__PURE__*/React.createElement(View, {
    style: [styles.elevator, style]
  }, isSticky && scrollY > 0 ? /*#__PURE__*/React.createElement(View, {
    style: styles.elevatorList__fixed
  }, /*#__PURE__*/React.createElement(Text, {
    style: styles.elevatorList__fixedTitle
  }, indexList[codeIndex][acceptKey])) : null, /*#__PURE__*/React.createElement(View, {
    style: [styles.elevatorList, {
      height
    }]
  }, /*#__PURE__*/React.createElement(FlatList, {
    style: styles.elevatorList__inner,
    data: indexList,
    renderItem: renderItem,
    initialNumToRender: 20,
    showsVerticalScrollIndicator: false,
    keyExtractor: (item, index) => '' + index,
    onScroll: onScroll,
    ref: listview
  })), indexList.length && scrollStart ? /*#__PURE__*/React.createElement(View, {
    style: styles.elevatorCodeCurrent
  }, /*#__PURE__*/React.createElement(Text, {
    style: styles.elevatorCodeCurrentText
  }, indexList[codeIndex][acceptKey])) : null, /*#__PURE__*/React.createElement(View, {
    style: [styles.elevatorBars, {
      transform: transformBar
    }],
    onLayout: getBarInfo
  }, /*#__PURE__*/React.createElement(animated.View, _extends({
    style: styles.elevatorBars__inner
  }, panResponder.panHandlers), indexList.map((item, index) => {
    return /*#__PURE__*/React.createElement(Text, {
      style: [styles.elevatorBars__inner__item, {
        height: spaceHeight
      }, item[acceptKey] === indexList[codeIndex][acceptKey] && styles.elevatorBars__inner__itemActive],
      key: item[acceptKey],
      onPress: () => handleClickIndex(item[acceptKey], index)
    }, item[acceptKey]);
  }))));
};
Elevator.defaultProps = defaultProps;
Elevator.displayName = 'NutElevator';
//# sourceMappingURL=elevator.js.map