import React, { useRef, useEffect, useState } from 'react';
import { View, Text, Animated, Image, TouchableOpacity } from 'react-native';
import Icon from '../icon';
import { useConfig } from '../configprovider';
import fixednavStyles from './styles';
import pt from '../utils/pt';
const defaultProps = {
  visible: false,
  //   overlay: false,
  navList: [],
  activeText: '',
  unActiveText: '',
  type: 'right',
  position: {
    top: 'auto',
    bottom: 'auto'
  },
  onSelected: () => {},
  onChange: () => {}
};
export const FixedNav = props => {
  const {
    // overlay,
    visible,
    navList,
    activeText,
    unActiveText,
    position,
    onChange,
    onSelected,
    type,
    slotList,
    slotBtn
  } = {
    ...defaultProps,
    ...props
  };
  const {
    locale,
    theme
  } = useConfig();
  const styles = fixednavStyles(theme);
  const fadeAnim = useRef(new Animated.Value(type === 'left' ? -pt(375) : pt(375))).current;
  const [navWidth, setNavWidth] = useState(375);
  const onSelectCb = (event, item) => {
    onSelected(item, event);
  };
  const onUpdateValue = function () {
    let value = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : !visible;
    onChange(value);
  };
  const getNavInfo = e => {
    const {
      width
    } = e.nativeEvent.layout;
    setNavWidth(width);
  };
  useEffect(() => {
    console.log(fadeAnim);
    Animated.timing(fadeAnim, {
      toValue: visible ? 0 : type === 'left' ? -navWidth : navWidth,
      duration: 200,
      useNativeDriver: true
    }).start();
  }, [fadeAnim, navWidth, visible, type]);
  return /*#__PURE__*/React.createElement(View, {
    style: [styles.nutFixednav, type === 'left' && styles.nutFixednavLeft, position]
  }, /*#__PURE__*/React.createElement(View, {
    style: styles.nutFixednavList
  }, /*#__PURE__*/React.createElement(Animated.View, {
    style: [styles.nutFixednav__list, {
      transform: [{
        translateX: fadeAnim
      }]
    }, type === 'left' && styles.nutFixednav__listLeft],
    onLayout: getNavInfo
  }, /*#__PURE__*/React.createElement(React.Fragment, null, slotList || navList.map((item, index) => {
    return /*#__PURE__*/React.createElement(TouchableOpacity, {
      activeOpacity: 1,
      style: styles.nutFixednav__listItem,
      onPress: event => onSelectCb(event, item),
      key: item.id || index
    }, /*#__PURE__*/React.createElement(Image, {
      style: styles.nutFixednav__listImage,
      source: {
        uri: item.icon
      }
    }), /*#__PURE__*/React.createElement(Text, {
      style: styles.nutFixednav__listText
    }, item.text), item.num && /*#__PURE__*/React.createElement(Text, {
      style: styles.nutFixednav__b
    }, item.num));
  })))), /*#__PURE__*/React.createElement(TouchableOpacity, {
    style: [styles.nutFixednav__btn, type === 'left' && styles.nutFixednav__btnLeft],
    activeOpacity: 1,
    onPress: () => onUpdateValue()
  }, /*#__PURE__*/React.createElement(React.Fragment, null, slotBtn || /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Icon, {
    style: {
      transform: [{
        rotate: visible ? '180deg' : '0deg'
      }]
    },
    name: "left",
    color: "#fff"
  }), /*#__PURE__*/React.createElement(Text, {
    style: styles.nutFixednav__btnText
  }, visible ? activeText || locale.fixednav.activeText : unActiveText || locale.fixednav.unActiveText)))));
};
FixedNav.defaultProps = defaultProps;
FixedNav.displayName = 'NutFixedNav';
//# sourceMappingURL=fixednav.js.map