import React, { useState, useEffect, useRef } from 'react';
import { Animated, Easing, Modal, TouchableOpacity, View } from 'react-native';
import Icon from '../icon/index';
import { ComponentDefaults } from '../utils/typings';
import deviceWidth from '../utils/deviceWidth';
import deviceHeight from '../utils/deviceHeight';
import statusBarHeight from '../utils/statusBarHeight';
import { useConfig } from '../configprovider';
import popupStyles from './styles';
const defaultProps = {
  ...ComponentDefaults,
  position: 'center',
  style: {},
  closeable: false,
  closeIconPosition: 'top-right',
  closeIcon: 'close',
  destroyOnClose: true,
  overlay: true,
  round: false,
  onOpen: () => {},
  onClose: () => {},
  onClick: e => {},
  onOpened: e => {},
  onClosed: e => {},
  onClickOverlay: e => {},
  onClickCloseIcon: e => {}
  //...defaultOverlayProps,
};

let _zIndex = 2000;
export const Popup = props => {
  const {
    children,
    visible,
    overlay,
    closeOnClickOverlay,
    overlayStyle,
    zIndex,
    duration,
    closeable,
    closeIconPosition,
    closeIcon,
    style,
    round,
    position,
    destroyOnClose,
    onOpen,
    onClose,
    onClickOverlay,
    onClickCloseIcon,
    onOpened,
    onClosed,
    onClick
  } = props;
  const {
    theme
  } = useConfig();
  const mStyles = popupStyles(theme);
  const [index, setIndex] = useState(zIndex || _zIndex);
  const [innerVisible, setInnerVisible] = useState(visible);
  const [showChildren, setShowChildren] = useState(true);
  const [viewWidth, setViewWidth] = useState(0);
  const baseStyle = {
    zIndex: index
  };
  const overlayStyles = {
    ...overlayStyle,
    ...baseStyle
  };
  const popStyles = {
    ...style,
    ...baseStyle
  };
  const open = () => {
    if (!innerVisible) {
      setInnerVisible(true);
      setIndex(++_zIndex);
    }
    if (destroyOnClose) {
      setShowChildren(true);
    }
    onOpen && onOpen();
  };
  const close = () => {
    if (innerVisible) {
      setInnerVisible(false);
      if (destroyOnClose) {
        setShowChildren(false);
        onClose && onClose();
      }
    }
  };
  const onHandleClickOverlay = e => {
    if (closeOnClickOverlay) {
      onClickOverlay && onClickOverlay(e);
      close();
    }
  };
  const onHandleClick = e => {
    onClose && onClose();
  };
  const onHandleClickCloseIcon = e => {
    onClickCloseIcon && onClickCloseIcon(e);
    close();
  };
  const animatedValue = useRef(new Animated.Value(0)).current;
  Animated.timing(animatedValue, {
    toValue: innerVisible ? 1 : 0,
    duration: duration ? duration * 1000 : 300,
    easing: Easing.ease,
    useNativeDriver: true
  }).start();
  const getStyles = () => {
    let styles = {};
    switch (position) {
      case 'top':
        if (round) {
          styles = mStyles.nut_pop_top_radius;
        } else {
          styles = mStyles.nut_pop_top;
        }
        break;
      case 'center':
        if (round) {
          styles = {
            top: (deviceHeight - (statusBarHeight ? statusBarHeight : 0)) / 2 - (popStyles !== null && popStyles !== void 0 && popStyles.paddingTop ? parseInt(String(popStyles.paddingTop)) : 0),
            left: (deviceWidth - viewWidth) / 2,
            borderRadius: 15
          };
        } else {
          styles = {
            top: (deviceHeight - (statusBarHeight ? statusBarHeight : 0)) / 2 - (popStyles !== null && popStyles !== void 0 && popStyles.paddingTop ? parseInt(String(popStyles.paddingTop)) : 0),
            left: (deviceWidth - viewWidth) / 2
          };
        }
        break;
      case 'bottom':
        if (round) {
          styles = mStyles.nut_pop_bottom_radius;
        } else {
          styles = mStyles.nut_pop_bottom;
        }
        break;
      case 'right':
        styles = mStyles.nut_pop_right;
        break;
      case 'left':
        styles = mStyles.nut_pop_left;
        break;
      default:
        break;
    }
    return styles;
  };
  const getIconStyles = () => {
    let styles = {};
    switch (closeIconPosition) {
      case 'top-left':
        styles = mStyles.nut_icon_top_left;
        break;
      case 'top-right':
        styles = mStyles.nut_icon_top_right;
        break;
      case 'bottom-left':
        styles = mStyles.nut_icon_bottom_left;
        break;
      case 'bottom-right':
        styles = mStyles.nut_icon_bottom_right;
        break;
      default:
        break;
    }
    return styles;
  };
  const renderPop = () => {
    return /*#__PURE__*/React.createElement(Animated.View, {
      style: {
        position: 'absolute',
        opacity: animatedValue,
        overflow: 'hidden',
        ...popStyles,
        ...getStyles()
      }
    }, showChildren ? /*#__PURE__*/React.createElement(View, {
      style: {
        flex: 1
      },
      onLayout: event => {
        if (position === 'center' && viewWidth === 0) {
          var _event$nativeEvent, _event$nativeEvent$la;
          setViewWidth(event === null || event === void 0 ? void 0 : (_event$nativeEvent = event.nativeEvent) === null || _event$nativeEvent === void 0 ? void 0 : (_event$nativeEvent$la = _event$nativeEvent.layout) === null || _event$nativeEvent$la === void 0 ? void 0 : _event$nativeEvent$la.width);
        }
      }
    }, children) : null, closeable ? /*#__PURE__*/React.createElement(TouchableOpacity, {
      style: {
        position: 'absolute',
        ...getIconStyles()
      },
      onPress: e => {
        onClickCloseIcon && onClickCloseIcon(e);
      }
    }, /*#__PURE__*/React.createElement(Icon, {
      onPress: onHandleClickCloseIcon,
      name: closeIcon,
      size: "18"
    })) : null);
  };
  const renderNode = () => {
    return /*#__PURE__*/React.createElement(Modal, {
      visible: visible,
      transparent: true,
      animationType: "none",
      onRequestClose: onHandleClick
    }, overlay ? /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(TouchableOpacity, {
      style: mStyles.nut_pop_full,
      activeOpacity: 1,
      onPress: onHandleClickOverlay
    }, /*#__PURE__*/React.createElement(View, {
      style: mStyles.nut_popbg_full
    })), renderPop()) : /*#__PURE__*/React.createElement(React.Fragment, null, renderPop()));
  };
  useEffect(() => {
    visible && open();
    !visible && close();
  }, [visible]);
  return renderNode();
};
Popup.defaultProps = defaultProps;
Popup.displayName = 'NutPopup';
//# sourceMappingURL=popup.js.map