import React, { useCallback, useContext } from 'react';
import { TouchableHighlight, View, Text } from 'react-native';
import RadioContext from './context';
import RadioGroup from '../radiogroup';
import Icon from '../icon/index';
import toObj from '../utils/style-to-obj';
import fConStyle from '../utils/filter-container-style';
import fTextStyle from '../utils/filter-text-style';
import { useConfig } from '../configprovider';
import radioStyles from './styles';
const defaultProps = {
  disabled: false,
  checked: false,
  shape: 'round',
  value: '',
  textPosition: 'right',
  iconName: 'check-normal',
  iconActiveName: 'check-checked',
  iconSize: 18,
  onChange: e => {}
};
export const Radio = props => {
  const {
    children
  } = {
    ...defaultProps,
    ...props
  };
  const {
    disabled,
    checked,
    shape,
    textPosition,
    value,
    iconName,
    iconActiveName,
    iconSize,
    onChange,
    style
  } = props;
  const context = useContext(RadioContext);
  const {
    theme
  } = useConfig();
  const styles = radioStyles(theme);
  const onPressCallback = useCallback(e => {
    if (disabled || checked) return;
    onChange && onChange(e);
    context && context.onChange(value);
  }, [disabled, checked]);
  const wrapStyle = [styles[`shape${shape}Container`], styles[`${shape}Checked${checked}`], fConStyle(toObj(style || {})), styles[`${shape}Disabled${disabled}`]];
  const textStyle = [styles[`textDefault${shape}`], fTextStyle(toObj(style || {})), styles[`textChecked${shape}${checked}`], styles[`textPosition${textPosition}`]];
  const renderRound = () => {
    if (textPosition === 'left') {
      return [/*#__PURE__*/React.createElement(Text, {
        key: 1,
        style: textStyle
      }, children), /*#__PURE__*/React.createElement(Icon, {
        key: 2,
        name: checked ? iconActiveName : iconName,
        size: iconSize,
        color: checked ? '#f0250f' : '#d6d6d6'
      })];
    }
    return [/*#__PURE__*/React.createElement(Icon, {
      key: 1,
      name: checked ? iconActiveName : iconName,
      size: iconSize,
      color: checked ? '#f0250f' : '#d6d6d6',
      style: styles.mr10
    }), /*#__PURE__*/React.createElement(Text, {
      key: 2,
      style: textStyle
    }, children)];
  };
  const renderButton = () => {
    return /*#__PURE__*/React.createElement(Text, {
      style: textStyle
    }, children);
  };
  if (disabled) {
    return /*#__PURE__*/React.createElement(View, {
      style: wrapStyle
    }, shape === 'round' ? renderRound() : renderButton());
  }
  return /*#__PURE__*/React.createElement(TouchableHighlight, {
    underlayColor: null,
    activeOpacity: 1,
    onPress: onPressCallback
  }, /*#__PURE__*/React.createElement(View, {
    style: wrapStyle
  }, shape === 'round' ? renderRound() : renderButton()));
};
Radio.defaultProps = defaultProps;
Radio.displayName = 'NutRadio';
Radio.RadioGroup = RadioGroup;
//# sourceMappingURL=radio.js.map