import React, { useEffect, useState } from 'react';
import { View, Text, ScrollView } from 'react-native';
import Popup from '../popup';
import TimePannel from '../timepannel/index';
import TimeDetail from '../timedetail/index';
import deviceWidth from '../utils/deviceWidth';
import { useConfig } from '../configprovider';
import timeSelectStyles from './styles';
const defaultProps = {
  style: {},
  visible: false,
  height: '20%',
  multiple: false,
  currentKey: 0,
  currentTime: [],
  title: '取件时间',
  dates: [],
  times: []
};
export const TimeSelect = props => {
  const {
    visible,
    height,
    title,
    currentKey,
    currentTime,
    dates,
    times,
    multiple,
    select,
    pannelChange,
    timeChange,
    onSelect,
    onPannelChange,
    onTimeChange
  } = {
    ...defaultProps,
    ...props
  };
  const {
    theme
  } = useConfig();
  const mStyles = timeSelectStyles(theme);
  const [activeKey, setActiveKey] = useState(currentKey);
  const [activeTime, setActiveTime] = useState(currentTime.length ? currentTime : [{
    key: currentKey,
    list: []
  }]);
  const [popVisible, setPopVisible] = useState(visible);
  const popStyle = {
    width: '100%',
    height,
    backgroundColor: '#fff'
  };

  // popup 的关闭回调, 执行 select 函数更改外部 visible
  const closeFun = () => {
    if (onSelect) {
      onSelect(activeTime);
    } else if (select) {
      select(activeTime);
    }
  };
  // 选择配送时间回调
  const handleSelectTime = time => {
    let curTimeData = {};
    let curIndex = -1;
    for (let i = 0; i < activeTime.length; i++) {
      if (String(activeTime[i].key) === String(activeKey)) {
        curTimeData = activeTime[i];
        curIndex = i;
        break;
      }
    }
    const curTimeIndex = curTimeData.list.findIndex(item => String(item) === String(time));
    if (curTimeIndex === -1) {
      curTimeData.list.push(time);
    } else {
      curTimeData.list.splice(curTimeIndex, 1);
    }
    const resultTimeData = [...activeTime];
    resultTimeData.splice(curIndex, 1, curTimeData);
    setActiveTime(resultTimeData);
    if (onTimeChange) {
      onTimeChange(time, resultTimeData);
    } else if (timeChange) {
      timeChange(time, resultTimeData);
    }
  };
  // 选择日期的回调
  const handleChange = pannelKey => {
    const resultTimeData = [...activeTime];
    if (String(pannelKey) !== String(activeKey)) {
      setActiveKey === null || setActiveKey === void 0 ? void 0 : setActiveKey(pannelKey);
      if (multiple) {
        const curTimeDataIndex = activeTime.findIndex(item => String(item.key) === String(pannelKey));
        if (curTimeDataIndex === -1) {
          resultTimeData.push({
            key: pannelKey,
            list: []
          });
          setActiveTime(resultTimeData);
        }
      } else {
        setActiveTime([{
          key: pannelKey,
          list: []
        }]);
      }
    }
    if (onPannelChange) {
      onPannelChange(pannelKey, resultTimeData);
    } else if (pannelChange) {
      pannelChange(pannelKey, resultTimeData);
    }
  };
  // 选中的日期增加 active 类名
  const getTimePannelClass = dataItem => {
    if (String(dataItem['pannel-key']) === String(activeKey)) {
      return 'active';
    }
    return 'noactive';
  };
  // 根据外部传入 visible 进行组件的显隐展示
  useEffect(() => {
    setPopVisible(visible);
  }, [visible]);
  return /*#__PURE__*/React.createElement(Popup, {
    closeable: true,
    round: true,
    closeOnClickOverlay: true,
    visible: popVisible,
    position: "bottom",
    style: popStyle,
    onClose: () => {
      closeFun();
    },
    onClickCloseIcon: () => {
      closeFun();
    }
  }, /*#__PURE__*/React.createElement(View, {
    style: mStyles.nut_timeselect_container
  }, /*#__PURE__*/React.createElement(View, {
    style: mStyles.nut_timeselect_title
  }, /*#__PURE__*/React.createElement(Text, null, title)), /*#__PURE__*/React.createElement(View, {
    style: {
      flexDirection: 'row'
    }
  }, /*#__PURE__*/React.createElement(ScrollView, {
    style: {
      width: deviceWidth * 2 / 5
    }
  }, /*#__PURE__*/React.createElement(View, null, dates.map((dataItem, index) => /*#__PURE__*/React.createElement(TimePannel, {
    date: dataItem.date,
    className: getTimePannelClass(dataItem),
    key: String(dataItem['pannel-key'] || index),
    curKey: String(dataItem['pannel-key'] || index),
    change: handleChange
  })))), /*#__PURE__*/React.createElement(ScrollView, {
    style: {
      width: deviceWidth * 3 / 5
    }
  }, /*#__PURE__*/React.createElement(TimeDetail, {
    times: times,
    currentKey: String(activeKey),
    currentTime: activeTime,
    select: handleSelectTime
  })))));
};
TimeSelect.defaultProps = defaultProps;
TimeSelect.displayName = 'NutTimeSelect';
//# sourceMappingURL=timeselect.js.map